@@ -11,6 +11,52 @@
 NULL
 
 
+#' @keywords internal
+copyClasses <- function(x, y) {
+  x.names <- names(x)
+  y.names <- names(y)
+  if (length(setdiff(x.names, y.names)) > 0) {
+    stop("Data frame x contains columns not present in data frame y.")
+  }
+  column.names <- intersect(x.names, y.names)
+  for (name in column.names) {
+    # Do the classes match?
+    if (!identical(class(x[[name]]), class(y[[name]])) || 
+        !identical(levels(x[[name]]), levels(y[[name]]))) {
+      # Convert to numeric or integer class
+      if (is.numeric(y[[name]])) {
+        if (is.integer(y[[name]])) {
+          x[[name]] <- as.integer(x[[name]])
+        } else {
+          x[[name]] <- as.numeric(x[[name]])
+        }
+      }
+      # Convert to factor or ordered class
+      if (is.factor(y[[name]])) {
+        if (is.ordered(y[[name]])) {
+          x[[name]] <- as.ordered(x[[name]])
+        } else {
+          x[[name]] <- as.factor(x[[name]])
+        }
+        levels(x[[name]]) <- levels(y[[name]])
+      }
+      # Convert to character
+      if (is.character(y[[name]])) {
+        x[[name]] <- as.character(x[[name]])
+      }
+      # Convert to logical
+      if (is.logical(y[[name]])) {
+        x[[name]] <- as.logical(x[[name]])
+      }
+    }
+  }
+  # Sanity check
+  stopifnot(all.equal(sapply(x[column.names], class), 
+                      sapply(y[column.names], class)))
+  x  # return x with copied classes
+}
+
+
 #' @keywords internal
 avgLogit <- function(x, which.class = 1L) {
   stopifnot(is.matrix(x))  # x should be a nclass by n probability matrix
