@@ -10,7 +10,7 @@ test_that("partial works correctly", {
   mtcars.lm <- lm(mpg ~ ., data = mtcars)
   pd1 <- partial(mtcars.lm, pred.var = "wt", grid.resolution = 1,
                  type = "regression", train = mtcars)
-  pd2 <- partial(mtcars.lm, pred.var = "wt", pred.grid = 1)
+  pd2 <- partial(mtcars.lm, pred.var = "wt", pred.grid = 1, check.class = FALSE)
   expect_is(pd1, "data.frame")
   expect_is(pd2, "data.frame")
   expect_is(partial(mtcars.lm, pred.var = "wt", plot = TRUE), "trellis")
