@@ -4,6 +4,34 @@ context("Utility functions")
 #   regression: mtcars
 #   classification: iris
 
+test_that("copyClasses works correctly", {
+  # Incorrect classes
+  set.seed(101)
+  d1 <- data.frame(x1 = 1:3 * 1.0, 
+                   x2 = rnorm(3), 
+                   x3 = letters[1:3], 
+                   x4 = as.factor(1:3),
+                   x5 = as.factor(1:3),
+                   x6 = c(1, 0, 1),
+                   stringsAsFactors = TRUE)
+
+  # Correct classes
+  set.seed(101)
+  d2 <- data.frame(x1 = 1:3, 
+                   x2 = rnorm(3), 
+                   x3 = letters[1:3], 
+                   x4 = as.factor(1:3),
+                   x5 = as.ordered(1:3),
+                   x6 = c(TRUE, FALSE, TRUE),
+                   stringsAsFactors = FALSE)
+
+  # Copy classes from d2 to d1
+  d3 <- copyClasses(d1, d2)
+  d4 <- copyClasses(d1[1:2, ], d2)
+  expect_identical(d2, d3)  
+  expect_identical(sapply(d2, levels), sapply(d4, levels))
+})
+
 test_that("avgLogit works correctly", {
   pm <- matrix(c(0.1, 0.3, 0.6), nrow = 1, ncol = 3, byrow = TRUE)
   expect_error(avgLogit(as.data.frame(pm)))
